@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -26,14 +26,14 @@
 /* Define values for Microsoft WAVE format */
 /*******************************************/
 /* FOURCC */
-#define RIFF            0x46464952      /* "RIFF" */
-#define WAVE            0x45564157      /* "WAVE" */
-#define FACT            0x74636166      /* "fact" */
-#define LIST            0x5453494c      /* "LIST" */
-#define BEXT            0x74786562      /* "bext" */
-#define JUNK            0x4B4E554A      /* "JUNK" */
-#define FMT             0x20746D66      /* "fmt " */
-#define DATA            0x61746164      /* "data" */
+#define RIFF 0x46464952 /* "RIFF" */
+#define WAVE 0x45564157 /* "WAVE" */
+#define FACT 0x74636166 /* "fact" */
+#define LIST 0x5453494c /* "LIST" */
+#define BEXT 0x74786562 /* "bext" */
+#define JUNK 0x4B4E554A /* "JUNK" */
+#define FMT  0x20746D66 /* "fmt " */
+#define DATA 0x61746164 /* "data" */
 /* Format tags */
 #define UNKNOWN_CODE    0x0000
 #define PCM_CODE        0x0001
@@ -49,13 +49,13 @@
 /* Stores the WAVE format information. */
 typedef struct WaveFormat
 {
-    Uint16 formattag;       /* Raw value of the first field in the fmt chunk data. */
-    Uint16 encoding;        /* Actual encoding, possibly from the extensible header. */
-    Uint16 channels;        /* Number of channels. */
-    Uint32 frequency;       /* Sampling rate in Hz. */
-    Uint32 byterate;        /* Average bytes per second. */
-    Uint16 blockalign;      /* Bytes per block. */
-    Uint16 bitspersample;   /* Currently supported are 8, 16, 24, 32, and 4 for ADPCM. */
+    Uint16 formattag;     /* Raw value of the first field in the fmt chunk data. */
+    Uint16 encoding;      /* Actual encoding, possibly from the extensible header. */
+    Uint16 channels;      /* Number of channels. */
+    Uint32 frequency;     /* Sampling rate in Hz. */
+    Uint32 byterate;      /* Average bytes per second. */
+    Uint16 blockalign;    /* Bytes per block. */
+    Uint16 bitspersample; /* Currently supported are 8, 16, 24, 32, and 4 for ADPCM. */
 
     /* Extra information size. Number of extra bytes starting at byte 18 in the
      * fmt chunk data. This is at least 22 for the extensible header.
@@ -66,11 +66,12 @@ typedef struct WaveFormat
     Uint16 validsamplebits;
     Uint32 samplesperblock; /* For compressed formats. Can be zero. Actually 16 bits in the header. */
     Uint32 channelmask;
-    Uint8 subformat[16];    /* A format GUID. */
+    Uint8 subformat[16]; /* A format GUID. */
 } WaveFormat;
 
 /* Stores information on the fact chunk. */
-typedef struct WaveFact {
+typedef struct WaveFact
+{
     /* Represents the state of the fact chunk in the WAVE file.
      * Set to -1 if the fact chunk is invalid.
      * Set to 0 if the fact chunk is not present
@@ -101,7 +102,8 @@ typedef struct WaveChunk
 } WaveChunk;
 
 /* Controls how the size of the RIFF chunk affects the loading of a WAVE file. */
-typedef enum WaveRiffSizeHint {
+typedef enum WaveRiffSizeHint
+{
     RiffSizeNoHint,
     RiffSizeForce,
     RiffSizeIgnoreZero,
@@ -110,7 +112,8 @@ typedef enum WaveRiffSizeHint {
 } WaveRiffSizeHint;
 
 /* Controls how a truncated WAVE file is handled. */
-typedef enum WaveTruncationHint {
+typedef enum WaveTruncationHint
+{
     TruncNoHint,
     TruncVeryStrict,
     TruncStrict,
@@ -119,7 +122,8 @@ typedef enum WaveTruncationHint {
 } WaveTruncationHint;
 
 /* Controls how the fact chunk affects the loading of a WAVE file. */
-typedef enum WaveFactChunkHint {
+typedef enum WaveFactChunkHint
+{
     FactNoHint,
     FactTruncate,
     FactStrict,
@@ -139,7 +143,7 @@ typedef struct WaveFile
      */
     Sint64 sampleframes;
 
-    void *decoderdata;   /* Some decoders require extra data for a state. */
+    void *decoderdata; /* Some decoders require extra data for a state. */
 
     WaveRiffSizeHint riffhint;
     WaveTruncationHint trunchint;
