@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -30,11 +30,12 @@
 
 #include <pipewire/extensions/metadata.h>
 #include <spa/param/audio/format-utils.h>
+#include <spa/utils/json.h>
 
 /*
  * The following keys are defined for compatability when building against older versions of Pipewire
- * prior to their introduction and can be removed if the minimum required Pipewire version is increased
- * to or beyond their point of introduction.
+ * prior to their introduction and can be removed if the minimum required Pipewire build version is
+ * increased to or beyond their point of introduction.
  */
 
 /*
@@ -53,6 +54,14 @@
 #define PW_KEY_NODE_RATE "node.rate"
 #endif
 
+/*
+ * Introduced in 0.3.44
+ * Taken from src/pipewire/keys.h
+ */
+#ifndef PW_KEY_TARGET_OBJECT
+#define PW_KEY_TARGET_OBJECT "target.object"
+#endif
+
 /*
  * This seems to be a sane lower limit as Pipewire
  * uses it in several of it's own modules.
@@ -62,12 +71,13 @@
 
 #define PW_POD_BUFFER_LENGTH         1024
 #define PW_THREAD_NAME_BUFFER_LENGTH 128
+#define PW_MAX_IDENTIFIER_LENGTH     256
 
 enum PW_READY_FLAGS
 {
     PW_READY_FLAG_BUFFER_ADDED = 0x1,
     PW_READY_FLAG_STREAM_READY = 0x2,
-    PW_READY_FLAG_ALL_BITS     = 0x3
+    PW_READY_FLAG_ALL_BITS = 0x3
 };
 
 #define PW_ID_TO_HANDLE(x) (void *)((uintptr_t)x)
@@ -76,7 +86,8 @@ enum PW_READY_FLAGS
 static SDL_bool pipewire_initialized = SDL_FALSE;
 
 /* Pipewire entry points */
-static void (*PIPEWIRE_pw_init)(int *, char **);
+static const char *(*PIPEWIRE_pw_get_library_version)(void);
+static void (*PIPEWIRE_pw_init)(int *, char ***);
 static void (*PIPEWIRE_pw_deinit)(void);
 static struct pw_thread_loop *(*PIPEWIRE_pw_thread_loop_new)(const char *, const struct spa_dict *);
 static void (*PIPEWIRE_pw_thread_loop_destroy)(struct pw_thread_loop *);
@@ -106,13 +117,16 @@ static struct pw_properties *(*PIPEWIRE_pw_properties_new)(const char *, ...)SPA
 static int (*PIPEWIRE_pw_properties_set)(struct pw_properties *, const char *, const char *);
 static int (*PIPEWIRE_pw_properties_setf)(struct pw_properties *, const char *, const char *, ...) SPA_PRINTF_FUNC(3, 4);
 
+static int pipewire_version_major;
+static int pipewire_version_minor;
+static int pipewire_version_patch;
+
 #ifdef SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC
 
 static const char *pipewire_library = SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC;
-static void       *pipewire_handle  = NULL;
+static void *pipewire_handle = NULL;
 
-static int
-pipewire_dlsym(const char *fn, void **addr)
+static int pipewire_dlsym(const char *fn, void **addr)
 {
     *addr = SDL_LoadFunction(pipewire_handle, fn);
     if (*addr == NULL) {
@@ -128,18 +142,13 @@ pipewire_dlsym(const char *fn, void **addr)
         return -1;                                             \
     }
 
-static int
-load_pipewire_library()
+static int load_pipewire_library()
 {
-    if ((pipewire_handle = SDL_LoadObject(pipewire_library))) {
-        return 0;
-    }
-
-    return -1;
+    pipewire_handle = SDL_LoadObject(pipewire_library);
+    return pipewire_handle != NULL ? 0 : -1;
 }
 
-static void
-unload_pipewire_library()
+static void unload_pipewire_library()
 {
     if (pipewire_handle) {
         SDL_UnloadObject(pipewire_handle);
@@ -151,22 +160,20 @@ unload_pipewire_library()
 
 #define SDL_PIPEWIRE_SYM(x) PIPEWIRE_##x = x
 
-static int
-load_pipewire_library()
+static int load_pipewire_library()
 {
     return 0;
 }
 
-static void
-unload_pipewire_library()
+static void unload_pipewire_library()
 { /* Nothing to do */
 }
 
 #endif /* SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC */
 
-static int
-load_pipewire_syms()
+static int load_pipewire_syms()
 {
+    SDL_PIPEWIRE_SYM(pw_get_library_version);
     SDL_PIPEWIRE_SYM(pw_init);
     SDL_PIPEWIRE_SYM(pw_deinit);
     SDL_PIPEWIRE_SYM(pw_thread_loop_new);
@@ -198,21 +205,36 @@ load_pipewire_syms()
     return 0;
 }
 
-static int
-init_pipewire_library()
+SDL_FORCE_INLINE SDL_bool pipewire_version_at_least(int major, int minor, int patch)
+{
+    return (pipewire_version_major >= major) &&
+           (pipewire_version_major > major || pipewire_version_minor >= minor) &&
+           (pipewire_version_major > major || pipewire_version_minor > minor || pipewire_version_patch >= patch);
+}
+
+static int init_pipewire_library()
 {
     if (!load_pipewire_library()) {
         if (!load_pipewire_syms()) {
-            PIPEWIRE_pw_init(NULL, NULL);
-            return 0;
+            int nargs;
+            const char *version = PIPEWIRE_pw_get_library_version();
+            nargs = SDL_sscanf(version, "%d.%d.%d", &pipewire_version_major, &pipewire_version_minor, &pipewire_version_patch);
+            if (nargs < 3) {
+                return -1;
+            }
+
+            /* SDL can build against 0.3.20, but requires 0.3.24 */
+            if (pipewire_version_at_least(0, 3, 24)) {
+                PIPEWIRE_pw_init(NULL, NULL);
+                return 0;
+            }
         }
     }
 
     return -1;
 }
 
-static void
-deinit_pipewire_library()
+static void deinit_pipewire_library()
 {
     PIPEWIRE_pw_deinit();
     unload_pipewire_library();
@@ -224,7 +246,8 @@ struct node_object
     struct spa_list link;
 
     Uint32 id;
-    int    seq;
+    int seq;
+    SDL_bool persist;
 
     /*
      * NOTE: If used, this is *must* be allocated with SDL_malloc() or similar
@@ -236,8 +259,8 @@ struct node_object
     void *userdata;
 
     struct pw_proxy *proxy;
-    struct spa_hook  node_listener;
-    struct spa_hook  core_listener;
+    struct spa_hook node_listener;
+    struct spa_hook core_listener;
 };
 
 /* A sink/source node used for stream I/O. */
@@ -245,35 +268,37 @@ struct io_node
 {
     struct spa_list link;
 
-    Uint32        id;
-    SDL_bool      is_capture;
+    Uint32 id;
+    SDL_bool is_capture;
     SDL_AudioSpec spec;
 
-    char name[];
+    const char *name; /* Friendly name */
+    const char *path; /* OS identifier (i.e. ALSA endpoint) */
+
+    char buf[]; /* Buffer to hold the name and path strings. */
 };
 
 /* The global hotplug thread and associated objects. */
 static struct pw_thread_loop *hotplug_loop;
-static struct pw_core        *hotplug_core;
-static struct pw_context     *hotplug_context;
-static struct pw_registry    *hotplug_registry;
-static struct spa_hook        hotplug_registry_listener;
-static struct spa_hook        hotplug_core_listener;
-static struct spa_list        hotplug_pending_list;
-static struct spa_list        hotplug_io_list;
-static int                    hotplug_init_seq_val;
-static SDL_bool               hotplug_init_complete;
-static SDL_bool               hotplug_events_enabled;
+static struct pw_core *hotplug_core;
+static struct pw_context *hotplug_context;
+static struct pw_registry *hotplug_registry;
+static struct spa_hook hotplug_registry_listener;
+static struct spa_hook hotplug_core_listener;
+static struct spa_list hotplug_pending_list;
+static struct spa_list hotplug_io_list;
+static int hotplug_init_seq_val;
+static SDL_bool hotplug_init_complete;
+static SDL_bool hotplug_events_enabled;
 
-static Uint32 pipewire_default_sink_id   = SPA_ID_INVALID;
-static Uint32 pipewire_default_source_id = SPA_ID_INVALID;
+static char *pipewire_default_sink_id = NULL;
+static char *pipewire_default_source_id = NULL;
 
 /* The active node list */
-static SDL_bool
-io_list_check_add(struct io_node *node)
+static SDL_bool io_list_check_add(struct io_node *node)
 {
     struct io_node *n;
-    SDL_bool        ret = SDL_TRUE;
+    SDL_bool ret = SDL_TRUE;
 
     /* See if the node is already in the list */
     spa_list_for_each (n, &hotplug_io_list, link) {
@@ -295,8 +320,7 @@ dup_found:
     return ret;
 }
 
-static void
-io_list_remove(Uint32 id)
+static void io_list_remove(Uint32 id)
 {
     struct io_node *n, *temp;
 
@@ -316,18 +340,17 @@ io_list_remove(Uint32 id)
     }
 }
 
-static void
-io_list_sort()
+static void io_list_sort()
 {
     struct io_node *default_sink = NULL, *default_source = NULL;
     struct io_node *n, *temp;
 
     /* Find and move the default nodes to the beginning of the list */
     spa_list_for_each_safe (n, temp, &hotplug_io_list, link) {
-        if (n->id == pipewire_default_sink_id) {
+        if (pipewire_default_sink_id != NULL && SDL_strcmp(n->path, pipewire_default_sink_id) == 0) {
             default_sink = n;
             spa_list_remove(&n->link);
-        } else if (n->id == pipewire_default_source_id) {
+        } else if (pipewire_default_source_id != NULL && SDL_strcmp(n->path, pipewire_default_source_id) == 0) {
             default_source = n;
             spa_list_remove(&n->link);
         }
@@ -342,8 +365,7 @@ io_list_sort()
     }
 }
 
-static void
-io_list_clear()
+static void io_list_clear()
 {
     struct io_node *n, *temp;
 
@@ -353,8 +375,29 @@ io_list_clear()
     }
 }
 
-static void
-node_object_destroy(struct node_object *node)
+static struct io_node *io_list_get_by_id(Uint32 id)
+{
+    struct io_node *n, *temp;
+    spa_list_for_each_safe (n, temp, &hotplug_io_list, link) {
+        if (n->id == id) {
+            return n;
+        }
+    }
+    return NULL;
+}
+
+static struct io_node *io_list_get_by_path(char *path)
+{
+    struct io_node *n, *temp;
+    spa_list_for_each_safe (n, temp, &hotplug_io_list, link) {
+        if (SDL_strcmp(n->path, path) == 0) {
+            return n;
+        }
+    }
+    return NULL;
+}
+
+static void node_object_destroy(struct node_object *node)
 {
     SDL_assert(node);
 
@@ -366,15 +409,13 @@ node_object_destroy(struct node_object *node)
 }
 
 /* The pending node list */
-static void
-pending_list_add(struct node_object *node)
+static void pending_list_add(struct node_object *node)
 {
     SDL_assert(node);
     spa_list_append(&hotplug_pending_list, &node->link);
 }
 
-static void
-pending_list_remove(Uint32 id)
+static void pending_list_remove(Uint32 id)
 {
     struct node_object *node, *temp;
 
@@ -385,8 +426,7 @@ pending_list_remove(Uint32 id)
     }
 }
 
-static void
-pending_list_clear()
+static void pending_list_clear()
 {
     struct node_object *node, *temp;
 
@@ -395,10 +435,9 @@ pending_list_clear()
     }
 }
 
-static void *
-node_object_new(Uint32 id, const char *type, Uint32 version, const void *funcs, const struct pw_core_events *core_events)
+static void *node_object_new(Uint32 id, const char *type, Uint32 version, const void *funcs, const struct pw_core_events *core_events)
 {
-    struct pw_proxy    *proxy;
+    struct pw_proxy *proxy;
     struct node_object *node;
 
     /* Create the proxy object */
@@ -411,7 +450,7 @@ node_object_new(Uint32 id, const char *type, Uint32 version, const void *funcs,
     node = PIPEWIRE_pw_proxy_get_user_data(proxy);
     SDL_zerop(node);
 
-    node->id    = id;
+    node->id = id;
     node->proxy = proxy;
 
     /* Add the callbacks */
@@ -425,8 +464,7 @@ node_object_new(Uint32 id, const char *type, Uint32 version, const void *funcs,
 }
 
 /* Core sync points */
-static void
-core_events_hotplug_init_callback(void *object, uint32_t id, int seq)
+static void core_events_hotplug_init_callback(void *object, uint32_t id, int seq)
 {
     if (id == PW_ID_CORE && seq == hotplug_init_seq_val) {
         /* This core listener is no longer needed. */
@@ -438,11 +476,10 @@ core_events_hotplug_init_callback(void *object, uint32_t id, int seq)
     }
 }
 
-static void
-core_events_interface_callback(void *object, uint32_t id, int seq)
+static void core_events_interface_callback(void *object, uint32_t id, int seq)
 {
     struct node_object *node = object;
-    struct io_node     *io   = node->userdata;
+    struct io_node *io = node->userdata;
 
     if (id == PW_ID_CORE && seq == node->seq) {
         /*
@@ -457,22 +494,20 @@ core_events_interface_callback(void *object, uint32_t id, int seq)
     }
 }
 
-static void
-core_events_metadata_callback(void *object, uint32_t id, int seq)
+static void core_events_metadata_callback(void *object, uint32_t id, int seq)
 {
     struct node_object *node = object;
 
-    if (id == PW_ID_CORE && seq == node->seq) {
+    if (id == PW_ID_CORE && seq == node->seq && !node->persist) {
         node_object_destroy(node);
     }
 }
 
 static const struct pw_core_events hotplug_init_core_events = { PW_VERSION_CORE_EVENTS, .done = core_events_hotplug_init_callback };
-static const struct pw_core_events interface_core_events    = { PW_VERSION_CORE_EVENTS, .done = core_events_interface_callback };
-static const struct pw_core_events metadata_core_events     = { PW_VERSION_CORE_EVENTS, .done = core_events_metadata_callback };
+static const struct pw_core_events interface_core_events = { PW_VERSION_CORE_EVENTS, .done = core_events_interface_callback };
+static const struct pw_core_events metadata_core_events = { PW_VERSION_CORE_EVENTS, .done = core_events_metadata_callback };
 
-static void
-hotplug_core_sync(struct node_object *node)
+static void hotplug_core_sync(struct node_object *node)
 {
     /*
      * Node sync events *must* come before the hotplug init sync events or the initial
@@ -488,12 +523,11 @@ hotplug_core_sync(struct node_object *node)
 }
 
 /* Helpers for retrieving values from params */
-static SDL_bool
-get_range_param(const struct spa_pod *param, Uint32 key, int *def, int *min, int *max)
+static SDL_bool get_range_param(const struct spa_pod *param, Uint32 key, int *def, int *min, int *max)
 {
     const struct spa_pod_prop *prop;
-    struct spa_pod            *value;
-    Uint32                     n_values, choice;
+    struct spa_pod *value;
+    Uint32 n_values, choice;
 
     prop = spa_pod_find_prop(param, NULL, key);
 
@@ -522,11 +556,10 @@ get_range_param(const struct spa_pod *param, Uint32 key, int *def, int *min, int
     return SDL_FALSE;
 }
 
-static SDL_bool
-get_int_param(const struct spa_pod *param, Uint32 key, int *val)
+static SDL_bool get_int_param(const struct spa_pod *param, Uint32 key, int *val)
 {
     const struct spa_pod_prop *prop;
-    Sint32                     v;
+    Sint32 v;
 
     prop = spa_pod_find_prop(param, NULL, key);
 
@@ -542,13 +575,12 @@ get_int_param(const struct spa_pod *param, Uint32 key, int *val)
 }
 
 /* Interface node callbacks */
-static void
-node_event_info(void *object, const struct pw_node_info *info)
+static void node_event_info(void *object, const struct pw_node_info *info)
 {
     struct node_object *node = object;
-    struct io_node     *io   = node->userdata;
-    const char         *prop_val;
-    Uint32              i;
+    struct io_node *io = node->userdata;
+    const char *prop_val;
+    Uint32 i;
 
     if (info) {
         prop_val = spa_dict_lookup(info->props, PW_KEY_AUDIO_CHANNELS);
@@ -565,11 +597,10 @@ node_event_info(void *object, const struct pw_node_info *info)
     }
 }
 
-static void
-node_event_param(void *object, int seq, uint32_t id, uint32_t index, uint32_t next, const struct spa_pod *param)
+static void node_event_param(void *object, int seq, uint32_t id, uint32_t index, uint32_t next, const struct spa_pod *param)
 {
     struct node_object *node = object;
-    struct io_node     *io   = node->userdata;
+    struct io_node *io = node->userdata;
 
     /* Get the default frequency */
     if (io->spec.freq == 0) {
@@ -591,17 +622,45 @@ node_event_param(void *object, int seq, uint32_t id, uint32_t index, uint32_t ne
 static const struct pw_node_events interface_node_events = { PW_VERSION_NODE_EVENTS, .info = node_event_info,
                                                              .param = node_event_param };
 
-/* Metadata node callback */
-static int
-metadata_property(void *object, Uint32 subject, const char *key, const char *type, const char *value)
+static char *get_name_from_json(const char *json)
 {
-    if (subject == PW_ID_CORE && key != NULL && value != NULL) {
-        Uint32 val = SDL_atoi(value);
+    struct spa_json parser[2];
+    char key[7]; /* "name" */
+    char value[PW_MAX_IDENTIFIER_LENGTH];
+    spa_json_init(&parser[0], json, SDL_strlen(json));
+    if (spa_json_enter_object(&parser[0], &parser[1]) <= 0) {
+        /* Not actually JSON */
+        return NULL;
+    }
+    if (spa_json_get_string(&parser[1], key, sizeof(key)) <= 0) {
+        /* Not actually a key/value pair */
+        return NULL;
+    }
+    if (spa_json_get_string(&parser[1], value, sizeof(value)) <= 0) {
+        /* Somehow had a key with no value? */
+        return NULL;
+    }
+    return SDL_strdup(value);
+}
 
+/* Metadata node callback */
+static int metadata_property(void *object, Uint32 subject, const char *key, const char *type, const char *value)
+{
+    struct node_object *node = object;
+
+    if (subject == PW_ID_CORE && key != NULL && value != NULL) {
         if (!SDL_strcmp(key, "default.audio.sink")) {
-            pipewire_default_sink_id = val;
+            if (pipewire_default_sink_id != NULL) {
+                SDL_free(pipewire_default_sink_id);
+            }
+            pipewire_default_sink_id = get_name_from_json(value);
+            node->persist = SDL_TRUE;
         } else if (!SDL_strcmp(key, "default.audio.source")) {
-            pipewire_default_source_id = val;
+            if (pipewire_default_source_id != NULL) {
+                SDL_free(pipewire_default_source_id);
+            }
+            pipewire_default_source_id = get_name_from_json(value);
+            node->persist = SDL_TRUE;
         }
     }
 
@@ -611,9 +670,8 @@ metadata_property(void *object, Uint32 subject, const char *key, const char *typ
 static const struct pw_metadata_events metadata_node_events = { PW_VERSION_METADATA_EVENTS, .property = metadata_property };
 
 /* Global registry callbacks */
-static void
-registry_event_global_callback(void *object, uint32_t id, uint32_t permissions, const char *type, uint32_t version,
-                               const struct spa_dict *props)
+static void registry_event_global_callback(void *object, uint32_t id, uint32_t permissions, const char *type, uint32_t version,
+                                           const struct spa_dict *props)
 {
     struct node_object *node;
 
@@ -622,10 +680,12 @@ registry_event_global_callback(void *object, uint32_t id, uint32_t permissions,
         const char *media_class = spa_dict_lookup(props, PW_KEY_MEDIA_CLASS);
 
         if (media_class) {
-            const char     *node_desc;
+            const char *node_desc;
+            const char *node_path;
             struct io_node *io;
-            SDL_bool        is_capture;
-            int             str_buffer_len;
+            SDL_bool is_capture;
+            int desc_buffer_len;
+            int path_buffer_len;
 
             /* Just want sink and capture */
             if (!SDL_strcasecmp(media_class, "Audio/Sink")) {
@@ -637,8 +697,9 @@ registry_event_global_callback(void *object, uint32_t id, uint32_t permissions,
             }
 
             node_desc = spa_dict_lookup(props, PW_KEY_NODE_DESCRIPTION);
+            node_path = spa_dict_lookup(props, PW_KEY_NODE_NAME);
 
-            if (node_desc) {
+            if (node_desc && node_path) {
                 node = node_object_new(id, type, version, &interface_node_events, &interface_core_events);
                 if (node == NULL) {
                     SDL_SetError("Pipewire: Failed to allocate interface node");
@@ -646,8 +707,9 @@ registry_event_global_callback(void *object, uint32_t id, uint32_t permissions,
                 }
 
                 /* Allocate and initialize the I/O node information struct */
-                str_buffer_len = SDL_strlen(node_desc) + 1;
-                node->userdata = io = SDL_calloc(1, sizeof(struct io_node) + str_buffer_len);
+                desc_buffer_len = SDL_strlen(node_desc) + 1;
+                path_buffer_len = SDL_strlen(node_path) + 1;
+                node->userdata = io = SDL_calloc(1, sizeof(struct io_node) + desc_buffer_len + path_buffer_len);
                 if (io == NULL) {
                     node_object_destroy(node);
                     SDL_OutOfMemory();
@@ -655,10 +717,13 @@ registry_event_global_callback(void *object, uint32_t id, uint32_t permissions,
                 }
 
                 /* Begin setting the node properties */
-                io->id          = id;
-                io->is_capture  = is_capture;
+                io->id = id;
+                io->is_capture = is_capture;
                 io->spec.format = AUDIO_F32; /* Pipewire uses floats internally, other formats require conversion. */
-                SDL_strlcpy(io->name, node_desc, str_buffer_len);
+                io->name = io->buf;
+                io->path = io->buf + desc_buffer_len;
+                SDL_strlcpy(io->buf, node_desc, desc_buffer_len);
+                SDL_strlcpy(io->buf + desc_buffer_len, node_path, path_buffer_len);
 
                 /* Update sync points */
                 hotplug_core_sync(node);
@@ -676,8 +741,7 @@ registry_event_global_callback(void *object, uint32_t id, uint32_t permissions,
     }
 }
 
-static void
-registry_event_remove_callback(void *object, uint32_t id)
+static void registry_event_remove_callback(void *object, uint32_t id)
 {
     io_list_remove(id);
     pending_list_remove(id);
@@ -687,8 +751,7 @@ static const struct pw_registry_events registry_events = { PW_VERSION_REGISTRY_E
                                                            .global_remove = registry_event_remove_callback };
 
 /* The hotplug thread */
-static int
-hotplug_loop_init()
+static int hotplug_loop_init()
 {
     int res;
 
@@ -731,8 +794,7 @@ hotplug_loop_init()
     return 0;
 }
 
-static void
-hotplug_loop_destroy()
+static void hotplug_loop_destroy()
 {
     if (hotplug_loop) {
         PIPEWIRE_pw_thread_loop_stop(hotplug_loop);
@@ -741,11 +803,17 @@ hotplug_loop_destroy()
     pending_list_clear();
     io_list_clear();
 
-    hotplug_init_complete  = SDL_FALSE;
+    hotplug_init_complete = SDL_FALSE;
     hotplug_events_enabled = SDL_FALSE;
 
-    pipewire_default_sink_id   = SPA_ID_INVALID;
-    pipewire_default_source_id = SPA_ID_INVALID;
+    if (pipewire_default_sink_id != NULL) {
+        SDL_free(pipewire_default_sink_id);
+        pipewire_default_sink_id = NULL;
+    }
+    if (pipewire_default_source_id != NULL) {
+        SDL_free(pipewire_default_source_id);
+        pipewire_default_source_id = NULL;
+    }
 
     if (hotplug_registry) {
         PIPEWIRE_pw_proxy_destroy((struct pw_proxy *)hotplug_registry);
@@ -768,8 +836,7 @@ hotplug_loop_destroy()
     }
 }
 
-static void
-PIPEWIRE_DetectDevices()
+static void PIPEWIRE_DetectDevices()
 {
     struct io_node *io;
 
@@ -811,11 +878,10 @@ static const enum spa_audio_channel PIPEWIRE_channel_map_8[] = { SPA_AUDIO_CHANN
 
 #define COPY_CHANNEL_MAP(c) SDL_memcpy(info->position, PIPEWIRE_channel_map_##c, sizeof(PIPEWIRE_channel_map_##c))
 
-static void
-initialize_spa_info(const SDL_AudioSpec *spec, struct spa_audio_info_raw *info)
+static void initialize_spa_info(const SDL_AudioSpec *spec, struct spa_audio_info_raw *info)
 {
     info->channels = spec->channels;
-    info->rate     = spec->freq;
+    info->rate = spec->freq;
 
     switch (spec->channels) {
     case 1:
@@ -879,14 +945,13 @@ initialize_spa_info(const SDL_AudioSpec *spec, struct spa_audio_info_raw *info)
     }
 }
 
-static void
-output_callback(void *data)
+static void output_callback(void *data)
 {
-    struct pw_buffer  *pw_buf;
+    struct pw_buffer *pw_buf;
     struct spa_buffer *spa_buf;
-    Uint8             *dst;
+    Uint8 *dst;
 
-    _THIS                    = (SDL_AudioDevice *)data;
+    _THIS = (SDL_AudioDevice *)data;
     struct pw_stream *stream = this->hidden->stream;
 
     /* Shutting down, don't do anything */
@@ -895,7 +960,8 @@ output_callback(void *data)
     }
 
     /* See if a buffer is available */
-    if ((pw_buf = PIPEWIRE_pw_stream_dequeue_buffer(stream)) == NULL) {
+    pw_buf = PIPEWIRE_pw_stream_dequeue_buffer(stream);
+    if (pw_buf == NULL) {
         return;
     }
 
@@ -910,6 +976,7 @@ output_callback(void *data)
      * and run the callback with the work buffer to keep the callback
      * firing regularly in case the audio is being used as a timer.
      */
+    SDL_LockMutex(this->mixer_lock);
     if (!SDL_AtomicGet(&this->paused)) {
         if (SDL_AtomicGet(&this->enabled)) {
             dst = spa_buf->datas[0].data;
@@ -919,18 +986,13 @@ output_callback(void *data)
         }
 
         if (!this->stream) {
-            SDL_LockMutex(this->mixer_lock);
             this->callbackspec.callback(this->callbackspec.userdata, dst, this->callbackspec.size);
-            SDL_UnlockMutex(this->mixer_lock);
         } else {
             int got;
 
             /* Fire the callback until we have enough to fill a buffer */
             while (SDL_AudioStreamAvailable(this->stream) < this->spec.size) {
-                SDL_LockMutex(this->mixer_lock);
                 this->callbackspec.callback(this->callbackspec.userdata, this->work_buffer, this->callbackspec.size);
-                SDL_UnlockMutex(this->mixer_lock);
-
                 SDL_AudioStreamPut(this->stream, this->work_buffer, this->callbackspec.size);
             }
 
@@ -940,21 +1002,21 @@ output_callback(void *data)
     } else {
         SDL_memset(spa_buf->datas[0].data, this->spec.silence, this->spec.size);
     }
+    SDL_UnlockMutex(this->mixer_lock);
 
     spa_buf->datas[0].chunk->offset = 0;
     spa_buf->datas[0].chunk->stride = this->hidden->stride;
-    spa_buf->datas[0].chunk->size   = this->spec.size;
+    spa_buf->datas[0].chunk->size = this->spec.size;
 
     PIPEWIRE_pw_stream_queue_buffer(stream, pw_buf);
 }
 
-static void
-input_callback(void *data)
+static void input_callback(void *data)
 {
-    struct pw_buffer  *pw_buf;
+    struct pw_buffer *pw_buf;
     struct spa_buffer *spa_buf;
-    Uint8             *src;
-    _THIS                    = (SDL_AudioDevice *)data;
+    Uint8 *src;
+    _THIS = (SDL_AudioDevice *)data;
     struct pw_stream *stream = this->hidden->stream;
 
     /* Shutting down, don't do anything */
@@ -963,20 +1025,20 @@ input_callback(void *data)
     }
 
     pw_buf = PIPEWIRE_pw_stream_dequeue_buffer(stream);
-    if (!pw_buf) {
+    if (pw_buf == NULL) {
         return;
     }
 
     spa_buf = pw_buf->buffer;
-
-    if ((src = (Uint8 *)spa_buf->datas[0].data) == NULL) {
+    (src = (Uint8 *)spa_buf->datas[0].data);
+    if (src == NULL) {
         return;
     }
 
     if (!SDL_AtomicGet(&this->paused)) {
         /* Calculate the offset and data size */
         const Uint32 offset = SPA_MIN(spa_buf->datas[0].chunk->offset, spa_buf->datas[0].maxsize);
-        const Uint32 size   = SPA_MIN(spa_buf->datas[0].chunk->size, spa_buf->datas[0].maxsize - offset);
+        const Uint32 size = SPA_MIN(spa_buf->datas[0].chunk->size, spa_buf->datas[0].maxsize - offset);
 
         src += offset;
 
@@ -1004,8 +1066,7 @@ input_callback(void *data)
     PIPEWIRE_pw_stream_queue_buffer(stream, pw_buf);
 }
 
-static void
-stream_add_buffer_callback(void *data, struct pw_buffer *buffer)
+static void stream_add_buffer_callback(void *data, struct pw_buffer *buffer)
 {
     _THIS = data;
 
@@ -1016,7 +1077,7 @@ stream_add_buffer_callback(void *data, struct pw_buffer *buffer)
          */
         if (this->spec.size > buffer->buffer->datas[0].maxsize) {
             this->spec.samples = buffer->buffer->datas[0].maxsize / this->hidden->stride;
-            this->spec.size    = buffer->buffer->datas[0].maxsize;
+            this->spec.size = buffer->buffer->datas[0].maxsize;
         }
     } else if (this->hidden->buffer == NULL) {
         /*
@@ -1028,15 +1089,14 @@ stream_add_buffer_callback(void *data, struct pw_buffer *buffer)
          * A packet size of 2 periods should be more than is ever needed.
          */
         this->hidden->input_buffer_packet_size = SPA_MAX(this->spec.size, buffer->buffer->datas[0].maxsize) * 2;
-        this->hidden->buffer                   = SDL_NewDataQueue(this->hidden->input_buffer_packet_size, this->hidden->input_buffer_packet_size);
+        this->hidden->buffer = SDL_NewDataQueue(this->hidden->input_buffer_packet_size, this->hidden->input_buffer_packet_size);
     }
 
     this->hidden->stream_init_status |= PW_READY_FLAG_BUFFER_ADDED;
     PIPEWIRE_pw_thread_loop_signal(this->hidden->loop, false);
 }
 
-static void
-stream_state_changed_callback(void *data, enum pw_stream_state old, enum pw_stream_state state, const char *error)
+static void stream_state_changed_callback(void *data, enum pw_stream_state old, enum pw_stream_state state, const char *error)
 {
     _THIS = data;
 
@@ -1051,15 +1111,14 @@ stream_state_changed_callback(void *data, enum pw_stream_state old, enum pw_stre
 
 static const struct pw_stream_events stream_output_events = { PW_VERSION_STREAM_EVENTS,
                                                               .state_changed = stream_state_changed_callback,
-                                                              .add_buffer    = stream_add_buffer_callback,
-                                                              .process       = output_callback };
-static const struct pw_stream_events stream_input_events  = { PW_VERSION_STREAM_EVENTS,
-                                                              .state_changed = stream_state_changed_callback,
-                                                              .add_buffer    = stream_add_buffer_callback,
-                                                              .process       = input_callback };
+                                                              .add_buffer = stream_add_buffer_callback,
+                                                              .process = output_callback };
+static const struct pw_stream_events stream_input_events = { PW_VERSION_STREAM_EVENTS,
+                                                             .state_changed = stream_state_changed_callback,
+                                                             .add_buffer = stream_add_buffer_callback,
+                                                             .process = input_callback };
 
-static int
-PIPEWIRE_OpenDevice(_THIS, const char *devname)
+static int PIPEWIRE_OpenDevice(_THIS, const char *devname)
 {
     /*
      * NOTE: The PW_STREAM_FLAG_RT_PROCESS flag can be set to call the stream
@@ -1070,32 +1129,32 @@ PIPEWIRE_OpenDevice(_THIS, const char *devname)
      */
     static const enum pw_stream_flags STREAM_FLAGS = PW_STREAM_FLAG_AUTOCONNECT | PW_STREAM_FLAG_MAP_BUFFERS;
 
-    char                         thread_name[PW_THREAD_NAME_BUFFER_LENGTH];
-    Uint8                        pod_buffer[PW_POD_BUFFER_LENGTH];
-    struct spa_pod_builder       b        = SPA_POD_BUILDER_INIT(pod_buffer, sizeof(pod_buffer));
-    struct spa_audio_info_raw    spa_info = { 0 };
-    const struct spa_pod        *params   = NULL;
+    char thread_name[PW_THREAD_NAME_BUFFER_LENGTH];
+    Uint8 pod_buffer[PW_POD_BUFFER_LENGTH];
+    struct spa_pod_builder b = SPA_POD_BUILDER_INIT(pod_buffer, sizeof(pod_buffer));
+    struct spa_audio_info_raw spa_info = { 0 };
+    const struct spa_pod *params = NULL;
     struct SDL_PrivateAudioData *priv;
-    struct pw_properties        *props;
-    const char                  *app_name, *stream_name, *stream_role, *error;
-    const Uint32                 node_id   = this->handle == NULL ? PW_ID_ANY : PW_HANDLE_TO_ID(this->handle);
-    SDL_bool                     iscapture = this->iscapture;
-    int                          res;
+    struct pw_properties *props;
+    const char *app_name, *stream_name, *stream_role, *error;
+    Uint32 node_id = this->handle == NULL ? PW_ID_ANY : PW_HANDLE_TO_ID(this->handle);
+    SDL_bool iscapture = this->iscapture;
+    int res;
 
     /* Clamp the period size to sane values */
     const int min_period = PW_MIN_SAMPLES * SPA_MAX(this->spec.freq / PW_BASE_CLOCK_RATE, 1);
 
     /* Get the hints for the application name, stream name and role */
     app_name = SDL_GetHint(SDL_HINT_AUDIO_DEVICE_APP_NAME);
-    if (!app_name || *app_name == '\0') {
+    if (app_name == NULL || *app_name == '\0') {
         app_name = SDL_GetHint(SDL_HINT_APP_NAME);
-        if (!app_name || *app_name == '\0') {
+        if (app_name == NULL || *app_name == '\0') {
             app_name = "SDL Application";
         }
     }
 
     stream_name = SDL_GetHint(SDL_HINT_AUDIO_DEVICE_STREAM_NAME);
-    if (!stream_name || *stream_name == '\0') {
+    if (stream_name == NULL || *stream_name == '\0') {
         stream_name = "Audio Stream";
     }
 
@@ -1104,7 +1163,7 @@ PIPEWIRE_OpenDevice(_THIS, const char *devname)
      * but 'Game' seems more appropriate for the majority of SDL applications.
      */
     stream_role = SDL_GetHint(SDL_HINT_AUDIO_DEVICE_STREAM_ROLE);
-    if (!stream_role || *stream_role == '\0') {
+    if (stream_role == NULL || *stream_role == '\0') {
         stream_role = "Game";
     }
 
@@ -1115,7 +1174,9 @@ PIPEWIRE_OpenDevice(_THIS, const char *devname)
         return SDL_SetError("Pipewire: Failed to set audio format parameters");
     }
 
-    if ((this->hidden = priv = SDL_calloc(1, sizeof(struct SDL_PrivateAudioData))) == NULL) {
+    priv = SDL_calloc(1, sizeof(struct SDL_PrivateAudioData));
+    this->hidden = priv;
+    if (priv == NULL) {
         return SDL_OutOfMemory();
     }
 
@@ -1124,26 +1185,17 @@ PIPEWIRE_OpenDevice(_THIS, const char *devname)
 
     if (this->spec.samples < min_period) {
         this->spec.samples = min_period;
-        this->spec.size    = this->spec.samples * priv->stride;
+        this->spec.size = this->spec.samples * priv->stride;
     }
 
-    SDL_snprintf(thread_name, sizeof(thread_name), "SDLAudio%c%ld", (iscapture) ? 'C' : 'P', (long)this->handle);
+    (void)SDL_snprintf(thread_name, sizeof(thread_name), "SDLAudio%c%ld", (iscapture) ? 'C' : 'P', (long)this->handle);
     priv->loop = PIPEWIRE_pw_thread_loop_new(thread_name, NULL);
     if (priv->loop == NULL) {
         return SDL_SetError("Pipewire: Failed to create stream loop (%i)", errno);
     }
 
-    /*
-     * Load the realtime module so Pipewire can set the loop thread to the appropriate priority.
-     *
-     * NOTE: Pipewire versions 0.3.22 or higher require the PW_KEY_CONFIG_NAME property (with client-rt.conf),
-     *       lower versions require explicitly specifying the 'rtkit' module.
-     *
-     *       PW_KEY_CONTEXT_PROFILE_MODULES is deprecated and can be safely removed if the minimum required
-     *       Pipewire version is increased to 0.3.22 or higher at some point.
-     */
-    props = PIPEWIRE_pw_properties_new(PW_KEY_CONFIG_NAME, "client-rt.conf",
-                                       PW_KEY_CONTEXT_PROFILE_MODULES, "default,rtkit", NULL);
+    /* Load the realtime module so Pipewire can set the loop thread to the appropriate priority. */
+    props = PIPEWIRE_pw_properties_new(PW_KEY_CONFIG_NAME, "client-rt.conf", NULL);
     if (props == NULL) {
         return SDL_SetError("Pipewire: Failed to create stream context properties (%i)", errno);
     }
@@ -1168,6 +1220,27 @@ PIPEWIRE_OpenDevice(_THIS, const char *devname)
     PIPEWIRE_pw_properties_setf(props, PW_KEY_NODE_RATE, "1/%u", this->spec.freq);
     PIPEWIRE_pw_properties_set(props, PW_KEY_NODE_ALWAYS_PROCESS, "true");
 
+    /*
+     * Pipewire 0.3.44 introduced PW_KEY_TARGET_OBJECT that takes either a path
+     * (PW_KEY_NODE_NAME) or node serial number (PE_KEY_OBJECT_SERIAL) to connect
+     * the stream to its target. The target_id parameter in pw_stream_connect() is
+     * now deprecated and should always be PW_ID_ANY.
+     */
+    if (pipewire_version_at_least(0, 3, 44)) {
+        if (node_id != PW_ID_ANY) {
+            const struct io_node *node;
+
+            PIPEWIRE_pw_thread_loop_lock(hotplug_loop);
+            node = io_list_get_by_id(node_id);
+            if (node != NULL) {
+                PIPEWIRE_pw_properties_set(props, PW_KEY_TARGET_OBJECT, node->path);
+            }
+            PIPEWIRE_pw_thread_loop_unlock(hotplug_loop);
+
+            node_id = PW_ID_ANY;
+        }
+    }
+
     /* Create the new stream */
     priv->stream = PIPEWIRE_pw_stream_new_simple(PIPEWIRE_pw_thread_loop_get_loop(priv->loop), stream_name, props,
                                                  iscapture ? &stream_input_events : &stream_output_events, this);
@@ -1231,8 +1304,45 @@ static void PIPEWIRE_CloseDevice(_THIS)
     SDL_free(this->hidden);
 }
 
-static void
-PIPEWIRE_Deinitialize()
+static int PIPEWIRE_GetDefaultAudioInfo(char **name, SDL_AudioSpec *spec, int iscapture)
+{
+    struct io_node *node;
+    char *target;
+    int ret = 0;
+
+    PIPEWIRE_pw_thread_loop_lock(hotplug_loop);
+
+    if (iscapture) {
+        if (pipewire_default_source_id == NULL) {
+            ret = SDL_SetError("PipeWire could not find a default source");
+            goto failed;
+        }
+        target = pipewire_default_source_id;
+    } else {
+        if (pipewire_default_sink_id == NULL) {
+            ret = SDL_SetError("PipeWire could not find a default sink");
+            goto failed;
+        }
+        target = pipewire_default_sink_id;
+    }
+
+    node = io_list_get_by_path(target);
+    if (node == NULL) {
+        ret = SDL_SetError("PipeWire device list is out of sync with defaults");
+        goto failed;
+    }
+
+    if (name != NULL) {
+        *name = SDL_strdup(node->name);
+    }
+    SDL_copyp(spec, &node->spec);
+
+failed:
+    PIPEWIRE_pw_thread_loop_unlock(hotplug_loop);
+    return ret;
+}
+
+static void PIPEWIRE_Deinitialize()
 {
     if (pipewire_initialized) {
         hotplug_loop_destroy();
@@ -1241,8 +1351,7 @@ PIPEWIRE_Deinitialize()
     }
 }
 
-static SDL_bool
-PIPEWIRE_Init(SDL_AudioDriverImpl *impl)
+static SDL_bool PIPEWIRE_Init(SDL_AudioDriverImpl *impl)
 {
     if (!pipewire_initialized) {
         if (init_pipewire_library() < 0) {
@@ -1259,12 +1368,14 @@ PIPEWIRE_Init(SDL_AudioDriverImpl *impl)
 
     /* Set the function pointers */
     impl->DetectDevices = PIPEWIRE_DetectDevices;
-    impl->OpenDevice    = PIPEWIRE_OpenDevice;
-    impl->CloseDevice   = PIPEWIRE_CloseDevice;
-    impl->Deinitialize  = PIPEWIRE_Deinitialize;
+    impl->OpenDevice = PIPEWIRE_OpenDevice;
+    impl->CloseDevice = PIPEWIRE_CloseDevice;
+    impl->Deinitialize = PIPEWIRE_Deinitialize;
+    impl->GetDefaultAudioInfo = PIPEWIRE_GetDefaultAudioInfo;
 
-    impl->HasCaptureSupport         = SDL_TRUE;
+    impl->HasCaptureSupport = SDL_TRUE;
     impl->ProvidesOwnCallbackThread = SDL_TRUE;
+    impl->SupportsNonPow2Samples = SDL_TRUE;
 
     return SDL_TRUE;
 }
