@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2021 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -23,7 +23,7 @@
 #ifdef SDL_INPUT_LINUXEV
 
 /* This is based on the linux joystick driver */
-/* References: https://www.kernel.org/doc/Documentation/input/input.txt 
+/* References: https://www.kernel.org/doc/Documentation/input/input.txt
  *             https://www.kernel.org/doc/Documentation/input/event-codes.txt
  *             /usr/include/linux/input.h
  *             The evtest application is also useful to debug the protocol
@@ -42,7 +42,7 @@
 #include "SDL_endian.h"
 #include "SDL_scancode.h"
 #include "../../events/SDL_events_c.h"
-#include "../../events/scancodes_linux.h" /* adds linux_scancode_table */
+#include "../../events/SDL_scancode_tables_c.h"
 #include "../../core/linux/SDL_evdev_capabilities.h"
 #include "../../core/linux/SDL_udev.h"
 
@@ -51,11 +51,15 @@
 #define SYN_DROPPED 3
 #endif
 #ifndef ABS_MT_SLOT
-#define ABS_MT_SLOT         0x2f
-#define ABS_MT_POSITION_X   0x35
-#define ABS_MT_POSITION_Y   0x36
-#define ABS_MT_TRACKING_ID  0x39
-#define ABS_MT_PRESSURE     0x3a
+#define ABS_MT_SLOT        0x2f
+#define ABS_MT_POSITION_X  0x35
+#define ABS_MT_POSITION_Y  0x36
+#define ABS_MT_TRACKING_ID 0x39
+#define ABS_MT_PRESSURE    0x3a
+#endif
+#ifndef REL_WHEEL_HI_RES
+#define REL_WHEEL_HI_RES  0x0b
+#define REL_HWHEEL_HI_RES 0x0c
 #endif
 
 typedef struct SDL_evdevlist_item
@@ -64,14 +68,15 @@ typedef struct SDL_evdevlist_item
     int fd;
 
     /* TODO: use this for every device, not just touchscreen */
-    int out_of_sync;
+    SDL_bool out_of_sync;
 
     /* TODO: expand on this to have data for every possible class (mouse,
        keyboard, touchpad, etc.). Also there's probably some things in here we
        can pull out to the SDL_evdevlist_item i.e. name */
-    int is_touchscreen;
-    struct {
-        char* name;
+    SDL_bool is_touchscreen;
+    struct
+    {
+        char *name;
 
         int min_x, max_x, range_x;
         int min_y, max_y, range_y;
@@ -79,8 +84,10 @@ typedef struct SDL_evdevlist_item
 
         int max_slots;
         int current_slot;
-        struct {
-            enum {
+        struct
+        {
+            enum
+            {
                 EVDEV_TOUCH_SLOTDELTA_NONE = 0,
                 EVDEV_TOUCH_SLOTDELTA_DOWN,
                 EVDEV_TOUCH_SLOTDELTA_UP,
@@ -88,9 +95,16 @@ typedef struct SDL_evdevlist_item
             } delta;
             int tracking_id;
             int x, y, pressure;
-        } * slots;
+        } *slots;
 
-    } * touchscreen_data;
+    } *touchscreen_data;
+
+    /* Mouse state */
+    SDL_bool high_res_wheel;
+    SDL_bool high_res_hwheel;
+    SDL_bool relative_mouse;
+    int mouse_x, mouse_y;
+    int mouse_wheel, mouse_hwheel;
 
     struct SDL_evdevlist_item *next;
 } SDL_evdevlist_item;
@@ -112,36 +126,32 @@ static SDL_Scancode SDL_EVDEV_translate_keycode(int keycode);
 static void SDL_EVDEV_sync_device(SDL_evdevlist_item *item);
 static int SDL_EVDEV_device_removed(const char *dev_path);
 
-#if SDL_USE_LIBUDEV
 static int SDL_EVDEV_device_added(const char *dev_path, int udev_class);
-static void SDL_EVDEV_udev_callback(SDL_UDEV_deviceevent udev_type, int udev_class,
-    const char *dev_path);
+#if SDL_USE_LIBUDEV
+static void SDL_EVDEV_udev_callback(SDL_UDEV_deviceevent udev_event, int udev_class, const char *dev_path);
 #endif /* SDL_USE_LIBUDEV */
 
 static Uint8 EVDEV_MouseButtons[] = {
-    SDL_BUTTON_LEFT,            /*  BTN_LEFT        0x110 */
-    SDL_BUTTON_RIGHT,           /*  BTN_RIGHT       0x111 */
-    SDL_BUTTON_MIDDLE,          /*  BTN_MIDDLE      0x112 */
-    SDL_BUTTON_X1,              /*  BTN_SIDE        0x113 */
-    SDL_BUTTON_X2,              /*  BTN_EXTRA       0x114 */
-    SDL_BUTTON_X2 + 1,          /*  BTN_FORWARD     0x115 */
-    SDL_BUTTON_X2 + 2,          /*  BTN_BACK        0x116 */
-    SDL_BUTTON_X2 + 3           /*  BTN_TASK        0x117 */
+    SDL_BUTTON_LEFT,   /*  BTN_LEFT        0x110 */
+    SDL_BUTTON_RIGHT,  /*  BTN_RIGHT       0x111 */
+    SDL_BUTTON_MIDDLE, /*  BTN_MIDDLE      0x112 */
+    SDL_BUTTON_X1,     /*  BTN_SIDE        0x113 */
+    SDL_BUTTON_X2,     /*  BTN_EXTRA       0x114 */
+    SDL_BUTTON_X2 + 1, /*  BTN_FORWARD     0x115 */
+    SDL_BUTTON_X2 + 2, /*  BTN_BACK        0x116 */
+    SDL_BUTTON_X2 + 3  /*  BTN_TASK        0x117 */
 };
 
-static int
-SDL_EVDEV_SetRelativeMouseMode(SDL_bool enabled)
+static int SDL_EVDEV_SetRelativeMouseMode(SDL_bool enabled)
 {
     /* Mice already send relative events through this interface */
     return 0;
 }
 
-
-int
-SDL_EVDEV_Init(void)
+int SDL_EVDEV_Init(void)
 {
     if (_this == NULL) {
-        _this = (SDL_EVDEV_PrivateData*)SDL_calloc(1, sizeof(*_this));
+        _this = (SDL_EVDEV_PrivateData *)SDL_calloc(1, sizeof(*_this));
         if (_this == NULL) {
             return SDL_OutOfMemory();
         }
@@ -164,7 +174,30 @@ SDL_EVDEV_Init(void)
         /* Force a scan to build the initial device list */
         SDL_UDEV_Scan();
 #else
-        /* TODO: Scan the devices manually, like a caveman */
+        {
+            /* Allow the user to specify a list of devices explicitly of
+               the form:
+                  deviceclass:path[,deviceclass:path[,...]]
+               where device class is an integer representing the
+               SDL_UDEV_deviceclass and path is the full path to
+               the event device. */
+            const char *devices = SDL_getenv("SDL_EVDEV_DEVICES");
+            if (devices) {
+                /* Assume this is the old use of the env var and it is not in
+                   ROM. */
+                char *rest = (char *)devices;
+                char *spec;
+                while ((spec = SDL_strtokr(rest, ",", &rest))) {
+                    char *endofcls = 0;
+                    long cls = SDL_strtol(spec, &endofcls, 0);
+                    if (endofcls) {
+                        SDL_EVDEV_device_added(endofcls + 1, cls);
+                    }
+                }
+            } else {
+                /* TODO: Scan the devices manually, like a caveman */
+            }
+        }
 #endif /* SDL_USE_LIBUDEV */
 
         _this->kbd = SDL_EVDEV_kbd_init();
@@ -177,8 +210,7 @@ SDL_EVDEV_Init(void)
     return 0;
 }
 
-void
-SDL_EVDEV_Quit(void)
+void SDL_EVDEV_Quit(void)
 {
     if (_this == NULL) {
         return;
@@ -195,7 +227,7 @@ SDL_EVDEV_Quit(void)
         SDL_EVDEV_kbd_quit(_this->kbd);
 
         /* Remove existing devices */
-        while(_this->first != NULL) {
+        while (_this->first != NULL) {
             SDL_EVDEV_device_removed(_this->first->path);
         }
 
@@ -210,23 +242,24 @@ SDL_EVDEV_Quit(void)
 
 #if SDL_USE_LIBUDEV
 static void SDL_EVDEV_udev_callback(SDL_UDEV_deviceevent udev_event, int udev_class,
-    const char* dev_path)
+                                    const char *dev_path)
 {
     if (dev_path == NULL) {
         return;
     }
 
-    switch(udev_event) {
+    switch (udev_event) {
     case SDL_UDEV_DEVICEADDED:
-        if (!(udev_class & (SDL_UDEV_DEVICE_MOUSE | SDL_UDEV_DEVICE_KEYBOARD |
-            SDL_UDEV_DEVICE_TOUCHSCREEN)))
+        if (!(udev_class & (SDL_UDEV_DEVICE_MOUSE | SDL_UDEV_DEVICE_KEYBOARD | SDL_UDEV_DEVICE_TOUCHSCREEN | SDL_UDEV_DEVICE_TOUCHPAD))) {
             return;
+        }
 
-        if ((udev_class & SDL_UDEV_DEVICE_JOYSTICK))
+        if (udev_class & SDL_UDEV_DEVICE_JOYSTICK) {
             return;
+        }
 
         SDL_EVDEV_device_added(dev_path, udev_class);
-        break;  
+        break;
     case SDL_UDEV_DEVICEREMOVED:
         SDL_EVDEV_device_removed(dev_path);
         break;
@@ -236,8 +269,7 @@ static void SDL_EVDEV_udev_callback(SDL_UDEV_deviceevent udev_event, int udev_cl
 }
 #endif /* SDL_USE_LIBUDEV */
 
-void 
-SDL_EVDEV_Poll(void)
+void SDL_EVDEV_Poll(void)
 {
     struct input_event events[32];
     int i, j, len;
@@ -258,7 +290,7 @@ SDL_EVDEV_Poll(void)
     mouse = SDL_GetMouse();
 
     for (item = _this->first; item != NULL; item = item->next) {
-        while ((len = read(item->fd, events, (sizeof events))) > 0) {
+        while ((len = read(item->fd, events, sizeof(events))) > 0) {
             len /= sizeof(events[0]);
             for (i = 0; i < len; ++i) {
                 /* special handling for touchscreen, that should eventually be
@@ -273,9 +305,9 @@ SDL_EVDEV_Poll(void)
                     if (events[i].code >= BTN_MOUSE && events[i].code < BTN_MOUSE + SDL_arraysize(EVDEV_MouseButtons)) {
                         mouse_button = events[i].code - BTN_MOUSE;
                         if (events[i].value == 0) {
-                            SDL_SendMouseButton(mouse->focus, mouse->mouseID, SDL_RELEASED, EVDEV_MouseButtons[mouse_button]);
+                            SDL_SendMouseButton(mouse->focus, (SDL_MouseID)item->fd, SDL_RELEASED, EVDEV_MouseButtons[mouse_button]);
                         } else if (events[i].value == 1) {
-                            SDL_SendMouseButton(mouse->focus, mouse->mouseID, SDL_PRESSED, EVDEV_MouseButtons[mouse_button]);
+                            SDL_SendMouseButton(mouse->focus, (SDL_MouseID)item->fd, SDL_PRESSED, EVDEV_MouseButtons[mouse_button]);
                         }
                         break;
                     }
@@ -286,10 +318,11 @@ SDL_EVDEV_Poll(void)
                        next finger after earlist is released) */
                     if (item->is_touchscreen && events[i].code == BTN_TOUCH) {
                         if (item->touchscreen_data->max_slots == 1) {
-                            if (events[i].value)
+                            if (events[i].value) {
                                 item->touchscreen_data->slots[0].delta = EVDEV_TOUCH_SLOTDELTA_DOWN;
-                            else
+                            } else {
                                 item->touchscreen_data->slots[0].delta = EVDEV_TOUCH_SLOTDELTA_UP;
+                            }
                         }
                         break;
                     }
@@ -306,15 +339,17 @@ SDL_EVDEV_Poll(void)
                     SDL_EVDEV_kbd_keycode(_this->kbd, events[i].code, events[i].value);
                     break;
                 case EV_ABS:
-                    switch(events[i].code) {
+                    switch (events[i].code) {
                     case ABS_MT_SLOT:
-                        if (!item->is_touchscreen) /* FIXME: temp hack */
+                        if (!item->is_touchscreen) { /* FIXME: temp hack */
                             break;
+                        }
                         item->touchscreen_data->current_slot = events[i].value;
                         break;
                     case ABS_MT_TRACKING_ID:
-                        if (!item->is_touchscreen) /* FIXME: temp hack */
+                        if (!item->is_touchscreen) { /* FIXME: temp hack */
                             break;
+                        }
                         if (events[i].value >= 0) {
                             item->touchscreen_data->slots[item->touchscreen_data->current_slot].tracking_id = events[i].value;
                             item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta = EVDEV_TOUCH_SLOTDELTA_DOWN;
@@ -323,24 +358,27 @@ SDL_EVDEV_Poll(void)
                         }
                         break;
                     case ABS_MT_POSITION_X:
-                        if (!item->is_touchscreen) /* FIXME: temp hack */
+                        if (!item->is_touchscreen) { /* FIXME: temp hack */
                             break;
+                        }
                         item->touchscreen_data->slots[item->touchscreen_data->current_slot].x = events[i].value;
                         if (item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta == EVDEV_TOUCH_SLOTDELTA_NONE) {
                             item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta = EVDEV_TOUCH_SLOTDELTA_MOVE;
                         }
                         break;
                     case ABS_MT_POSITION_Y:
-                        if (!item->is_touchscreen) /* FIXME: temp hack */
+                        if (!item->is_touchscreen) { /* FIXME: temp hack */
                             break;
+                        }
                         item->touchscreen_data->slots[item->touchscreen_data->current_slot].y = events[i].value;
                         if (item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta == EVDEV_TOUCH_SLOTDELTA_NONE) {
                             item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta = EVDEV_TOUCH_SLOTDELTA_MOVE;
                         }
                         break;
                     case ABS_MT_PRESSURE:
-                        if (!item->is_touchscreen) /* FIXME: temp hack */
+                        if (!item->is_touchscreen) { /* FIXME: temp hack */
                             break;
+                        }
                         item->touchscreen_data->slots[item->touchscreen_data->current_slot].pressure = events[i].value;
                         if (item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta == EVDEV_TOUCH_SLOTDELTA_NONE) {
                             item->touchscreen_data->slots[item->touchscreen_data->current_slot].delta = EVDEV_TOUCH_SLOTDELTA_MOVE;
@@ -348,37 +386,59 @@ SDL_EVDEV_Poll(void)
                         break;
                     case ABS_X:
                         if (item->is_touchscreen) {
-                            if (item->touchscreen_data->max_slots != 1)
+                            if (item->touchscreen_data->max_slots != 1) {
                                 break;
+                            }
                             item->touchscreen_data->slots[0].x = events[i].value;
-                        } else
-                            SDL_SendMouseMotion(mouse->focus, mouse->mouseID, SDL_FALSE, events[i].value, mouse->y);
+                        } else if (!item->relative_mouse) {
+                            /* FIXME: Normalize to input device's reported input range (EVIOCGABS) */
+                            item->mouse_x = events[i].value;
+                        }
                         break;
                     case ABS_Y:
                         if (item->is_touchscreen) {
-                            if (item->touchscreen_data->max_slots != 1)
+                            if (item->touchscreen_data->max_slots != 1) {
                                 break;
+                            }
                             item->touchscreen_data->slots[0].y = events[i].value;
-                        } else
-                            SDL_SendMouseMotion(mouse->focus, mouse->mouseID, SDL_FALSE, mouse->x, events[i].value);
+                        } else if (!item->relative_mouse) {
+                            /* FIXME: Normalize to input device's reported input range (EVIOCGABS) */
+                            item->mouse_y = events[i].value;
+                        }
                         break;
                     default:
                         break;
                     }
                     break;
                 case EV_REL:
-                    switch(events[i].code) {
+                    switch (events[i].code) {
                     case REL_X:
-                        SDL_SendMouseMotion(mouse->focus, mouse->mouseID, SDL_TRUE, events[i].value, 0);
+                        if (item->relative_mouse) {
+                            item->mouse_x += events[i].value;
+                        }
                         break;
                     case REL_Y:
-                        SDL_SendMouseMotion(mouse->focus, mouse->mouseID, SDL_TRUE, 0, events[i].value);
+                        if (item->relative_mouse) {
+                            item->mouse_y += events[i].value;
+                        }
                         break;
                     case REL_WHEEL:
-                        SDL_SendMouseWheel(mouse->focus, mouse->mouseID, 0, events[i].value, SDL_MOUSEWHEEL_NORMAL);
+                        if (!item->high_res_wheel) {
+                            item->mouse_wheel += events[i].value;
+                        }
+                        break;
+                    case REL_WHEEL_HI_RES:
+                        SDL_assert(item->high_res_wheel);
+                        item->mouse_wheel += events[i].value;
                         break;
                     case REL_HWHEEL:
-                        SDL_SendMouseWheel(mouse->focus, mouse->mouseID, events[i].value, 0, SDL_MOUSEWHEEL_NORMAL);
+                        if (!item->high_res_hwheel) {
+                            item->mouse_hwheel += events[i].value;
+                        }
+                        break;
+                    case REL_HWHEEL_HI_RES:
+                        SDL_assert(item->high_res_hwheel);
+                        item->mouse_hwheel += events[i].value;
                         break;
                     default:
                         break;
@@ -387,18 +447,32 @@ SDL_EVDEV_Poll(void)
                 case EV_SYN:
                     switch (events[i].code) {
                     case SYN_REPORT:
-                        if (!item->is_touchscreen) /* FIXME: temp hack */
-                            break;
+                        /* Send mouse axis changes together to ensure consistency and reduce event processing overhead */
+                        if (item->mouse_x != 0 || item->mouse_y != 0) {
+                            SDL_SendMouseMotion(mouse->focus, (SDL_MouseID)item->fd, item->relative_mouse, item->mouse_x, item->mouse_y);
+                            item->mouse_x = item->mouse_y = 0;
+                        }
+                        if (item->mouse_wheel != 0 || item->mouse_hwheel != 0) {
+                            SDL_SendMouseWheel(mouse->focus, (SDL_MouseID)item->fd,
+                                               item->mouse_hwheel / (item->high_res_hwheel ? 120.0f : 1.0f),
+                                               item->mouse_wheel / (item->high_res_wheel ? 120.0f : 1.0f),
+                                               SDL_MOUSEWHEEL_NORMAL);
+                            item->mouse_wheel = item->mouse_hwheel = 0;
+                        }
 
-                        for(j = 0; j < item->touchscreen_data->max_slots; j++) {
+                        if (!item->is_touchscreen) { /* FIXME: temp hack */
+                            break;
+                        }
+
+                        for (j = 0; j < item->touchscreen_data->max_slots; j++) {
                             norm_x = (float)(item->touchscreen_data->slots[j].x - item->touchscreen_data->min_x) /
-                                (float)item->touchscreen_data->range_x;
+                                     (float)item->touchscreen_data->range_x;
                             norm_y = (float)(item->touchscreen_data->slots[j].y - item->touchscreen_data->min_y) /
-                                (float)item->touchscreen_data->range_y;
+                                     (float)item->touchscreen_data->range_y;
 
                             if (item->touchscreen_data->range_pressure > 0) {
                                 norm_pressure = (float)(item->touchscreen_data->slots[j].pressure - item->touchscreen_data->min_pressure) /
-                                    (float)item->touchscreen_data->range_pressure;
+                                                (float)item->touchscreen_data->range_pressure;
                             } else {
                                 /* This touchscreen does not support pressure */
                                 norm_pressure = 1.0f;
@@ -407,7 +481,7 @@ SDL_EVDEV_Poll(void)
                             /* FIXME: the touch's window shouldn't be null, but
                              * the coordinate space of touch positions needs to
                              * be window-relative in that case. */
-                            switch(item->touchscreen_data->slots[j].delta) {
+                            switch (item->touchscreen_data->slots[j].delta) {
                             case EVDEV_TOUCH_SLOTDELTA_DOWN:
                                 SDL_SendTouch(item->fd, item->touchscreen_data->slots[j].tracking_id, NULL, SDL_TRUE, norm_x, norm_y, norm_pressure);
                                 item->touchscreen_data->slots[j].delta = EVDEV_TOUCH_SLOTDELTA_NONE;
@@ -426,12 +500,14 @@ SDL_EVDEV_Poll(void)
                             }
                         }
 
-                        if (item->out_of_sync)
-                            item->out_of_sync = 0;
+                        if (item->out_of_sync) {
+                            item->out_of_sync = SDL_FALSE;
+                        }
                         break;
                     case SYN_DROPPED:
-                        if (item->is_touchscreen)
-                            item->out_of_sync = 1;
+                        if (item->is_touchscreen) {
+                            item->out_of_sync = SDL_TRUE;
+                        }
                         SDL_EVDEV_sync_device(item);
                         break;
                     default:
@@ -440,49 +516,47 @@ SDL_EVDEV_Poll(void)
                     break;
                 }
             }
-        }    
+        }
     }
 }
 
-static SDL_Scancode
-SDL_EVDEV_translate_keycode(int keycode)
+static SDL_Scancode SDL_EVDEV_translate_keycode(int keycode)
 {
-    SDL_Scancode scancode = SDL_SCANCODE_UNKNOWN;
+    SDL_Scancode scancode = SDL_GetScancodeFromTable(SDL_SCANCODE_TABLE_LINUX, keycode);
 
-    if (keycode < SDL_arraysize(linux_scancode_table)) {
-        scancode = linux_scancode_table[keycode];
-
-        if (scancode == SDL_SCANCODE_UNKNOWN) {
-            /* BTN_TOUCH is handled elsewhere, but we might still end up here if
-               you get an unexpected BTN_TOUCH from something SDL believes is not
-               a touch device. In this case, we'd rather not get a misleading
-               SDL_Log message about an unknown key. */
-            if (keycode != BTN_TOUCH) {
-                SDL_Log("The key you just pressed is not recognized by SDL. To help "
+#ifdef DEBUG_SCANCODES
+    if (scancode == SDL_SCANCODE_UNKNOWN) {
+        /* BTN_TOUCH is handled elsewhere, but we might still end up here if
+           you get an unexpected BTN_TOUCH from something SDL believes is not
+           a touch device. In this case, we'd rather not get a misleading
+           SDL_Log message about an unknown key. */
+        if (keycode != BTN_TOUCH) {
+            SDL_Log("The key you just pressed is not recognized by SDL. To help "
                     "get this fixed, please report this to the SDL forums/mailing list "
-                    "<https://discourse.libsdl.org/> EVDEV KeyCode %d", keycode);
-            }
+                    "<https://discourse.libsdl.org/> EVDEV KeyCode %d",
+                    keycode);
         }
     }
+#endif /* DEBUG_SCANCODES */
 
     return scancode;
 }
 
-#ifdef SDL_USE_LIBUDEV
-static int
-SDL_EVDEV_init_touchscreen(SDL_evdevlist_item* item)
+static int SDL_EVDEV_init_touchscreen(SDL_evdevlist_item *item, int udev_class)
 {
     int ret, i;
     unsigned long xreq, yreq;
     char name[64];
     struct input_absinfo abs_info;
 
-    if (!item->is_touchscreen)
+    if (!item->is_touchscreen) {
         return 0;
+    }
 
     item->touchscreen_data = SDL_calloc(1, sizeof(*item->touchscreen_data));
-    if (item->touchscreen_data == NULL)
+    if (item->touchscreen_data == NULL) {
         return SDL_OutOfMemory();
+    }
 
     ret = ioctl(item->fd, EVIOCGNAME(sizeof(name)), name);
     if (ret < 0) {
@@ -552,13 +626,13 @@ SDL_EVDEV_init_touchscreen(SDL_evdevlist_item* item)
         return SDL_OutOfMemory();
     }
 
-    for(i = 0; i < item->touchscreen_data->max_slots; i++) {
+    for (i = 0; i < item->touchscreen_data->max_slots; i++) {
         item->touchscreen_data->slots[i].tracking_id = -1;
     }
 
     ret = SDL_AddTouch(item->fd, /* I guess our fd is unique enough */
-        SDL_TOUCH_DEVICE_DIRECT,
-        item->touchscreen_data->name);
+                       (udev_class & SDL_UDEV_DEVICE_TOUCHPAD) ? SDL_TOUCH_DEVICE_INDIRECT_ABSOLUTE : SDL_TOUCH_DEVICE_DIRECT,
+                       item->touchscreen_data->name);
     if (ret < 0) {
         SDL_free(item->touchscreen_data->slots);
         SDL_free(item->touchscreen_data->name);
@@ -568,12 +642,12 @@ SDL_EVDEV_init_touchscreen(SDL_evdevlist_item* item)
 
     return 0;
 }
-#endif /* SDL_USE_LIBUDEV */
 
-static void
-SDL_EVDEV_destroy_touchscreen(SDL_evdevlist_item* item) {
-    if (!item->is_touchscreen)
+static void SDL_EVDEV_destroy_touchscreen(SDL_evdevlist_item *item)
+{
+    if (!item->is_touchscreen) {
         return;
+    }
 
     SDL_DelTouch(item->fd);
     SDL_free(item->touchscreen_data->slots);
@@ -581,8 +655,7 @@ SDL_EVDEV_destroy_touchscreen(SDL_evdevlist_item* item) {
     SDL_free(item->touchscreen_data);
 }
 
-static void
-SDL_EVDEV_sync_device(SDL_evdevlist_item *item) 
+static void SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
 {
 #ifdef EVIOCGMTSLOTS
     int i, ret;
@@ -595,23 +668,24 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
      *
      * this is the structure we're trying to emulate
      */
-    Uint32* mt_req_code;
-    Sint32* mt_req_values;
+    Uint32 *mt_req_code;
+    Sint32 *mt_req_values;
     size_t mt_req_size;
 
     /* TODO: sync devices other than touchscreen */
-    if (!item->is_touchscreen)
+    if (!item->is_touchscreen) {
         return;
+    }
 
     mt_req_size = sizeof(*mt_req_code) +
-        sizeof(*mt_req_values) * item->touchscreen_data->max_slots;
+                  sizeof(*mt_req_values) * item->touchscreen_data->max_slots;
 
     mt_req_code = SDL_calloc(1, mt_req_size);
     if (mt_req_code == NULL) {
         return;
     }
 
-    mt_req_values = (Sint32*)mt_req_code + 1;
+    mt_req_values = (Sint32 *)mt_req_code + 1;
 
     *mt_req_code = ABS_MT_TRACKING_ID;
     ret = ioctl(item->fd, EVIOCGMTSLOTS(mt_req_size), mt_req_code);
@@ -619,7 +693,7 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
         SDL_free(mt_req_code);
         return;
     }
-    for(i = 0; i < item->touchscreen_data->max_slots; i++) {
+    for (i = 0; i < item->touchscreen_data->max_slots; i++) {
         /*
          * This doesn't account for the very edge case of the user removing their
          * finger and replacing it on the screen during the time we're out of sync,
@@ -634,7 +708,7 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
             item->touchscreen_data->slots[i].tracking_id = mt_req_values[i];
             item->touchscreen_data->slots[i].delta = EVDEV_TOUCH_SLOTDELTA_DOWN;
         } else if (item->touchscreen_data->slots[i].tracking_id >= 0 &&
-            mt_req_values[i] < 0) {
+                   mt_req_values[i] < 0) {
             item->touchscreen_data->slots[i].tracking_id = -1;
             item->touchscreen_data->slots[i].delta = EVDEV_TOUCH_SLOTDELTA_UP;
         }
@@ -646,7 +720,7 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
         SDL_free(mt_req_code);
         return;
     }
-    for(i = 0; i < item->touchscreen_data->max_slots; i++) {
+    for (i = 0; i < item->touchscreen_data->max_slots; i++) {
         if (item->touchscreen_data->slots[i].tracking_id >= 0 &&
             item->touchscreen_data->slots[i].x != mt_req_values[i]) {
             item->touchscreen_data->slots[i].x = mt_req_values[i];
@@ -664,7 +738,7 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
         SDL_free(mt_req_code);
         return;
     }
-    for(i = 0; i < item->touchscreen_data->max_slots; i++) {
+    for (i = 0; i < item->touchscreen_data->max_slots; i++) {
         if (item->touchscreen_data->slots[i].tracking_id >= 0 &&
             item->touchscreen_data->slots[i].y != mt_req_values[i]) {
             item->touchscreen_data->slots[i].y = mt_req_values[i];
@@ -682,7 +756,7 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
         SDL_free(mt_req_code);
         return;
     }
-    for(i = 0; i < item->touchscreen_data->max_slots; i++) {
+    for (i = 0; i < item->touchscreen_data->max_slots; i++) {
         if (item->touchscreen_data->slots[i].tracking_id >= 0 &&
             item->touchscreen_data->slots[i].pressure != mt_req_values[i]) {
             item->touchscreen_data->slots[i].pressure = mt_req_values[i];
@@ -706,26 +780,25 @@ SDL_EVDEV_sync_device(SDL_evdevlist_item *item)
 #endif /* EVIOCGMTSLOTS */
 }
 
-#if SDL_USE_LIBUDEV
-static int
-SDL_EVDEV_device_added(const char *dev_path, int udev_class)
+static int SDL_EVDEV_device_added(const char *dev_path, int udev_class)
 {
     int ret;
     SDL_evdevlist_item *item;
+    unsigned long relbit[NBITS(REL_MAX)] = { 0 };
 
     /* Check to make sure it's not already in list. */
     for (item = _this->first; item != NULL; item = item->next) {
         if (SDL_strcmp(dev_path, item->path) == 0) {
-            return -1;  /* already have this one */
+            return -1; /* already have this one */
         }
     }
 
-    item = (SDL_evdevlist_item *) SDL_calloc(1, sizeof (SDL_evdevlist_item));
+    item = (SDL_evdevlist_item *)SDL_calloc(1, sizeof(SDL_evdevlist_item));
     if (item == NULL) {
         return SDL_OutOfMemory();
     }
 
-    item->fd = open(dev_path, O_RDONLY | O_NONBLOCK);
+    item->fd = open(dev_path, O_RDONLY | O_NONBLOCK | O_CLOEXEC);
     if (item->fd < 0) {
         SDL_free(item);
         return SDL_SetError("Unable to open %s", dev_path);
@@ -738,11 +811,19 @@ SDL_EVDEV_device_added(const char *dev_path, int udev_class)
         return SDL_OutOfMemory();
     }
 
-    if (udev_class & SDL_UDEV_DEVICE_TOUCHSCREEN) {
-        item->is_touchscreen = 1;
+    if (ioctl(item->fd, EVIOCGBIT(EV_REL, sizeof(relbit)), relbit) >= 0) {
+        item->relative_mouse = test_bit(REL_X, relbit) && test_bit(REL_Y, relbit);
+        item->high_res_wheel = test_bit(REL_WHEEL_HI_RES, relbit);
+        item->high_res_hwheel = test_bit(REL_HWHEEL_HI_RES, relbit);
+    }
 
-        if ((ret = SDL_EVDEV_init_touchscreen(item)) < 0) {
+    /* For now, we just treat a touchpad like a touchscreen */
+    if (udev_class & (SDL_UDEV_DEVICE_TOUCHSCREEN | SDL_UDEV_DEVICE_TOUCHPAD)) {
+        item->is_touchscreen = SDL_TRUE;
+        ret = SDL_EVDEV_init_touchscreen(item, udev_class);
+        if (ret < 0) {
             close(item->fd);
+            SDL_free(item->path);
             SDL_free(item);
             return ret;
         }
@@ -759,10 +840,8 @@ SDL_EVDEV_device_added(const char *dev_path, int udev_class)
 
     return _this->num_devices++;
 }
-#endif /* SDL_USE_LIBUDEV */
 
-static int
-SDL_EVDEV_device_removed(const char *dev_path)
+static int SDL_EVDEV_device_removed(const char *dev_path)
 {
     SDL_evdevlist_item *item;
     SDL_evdevlist_item *prev = NULL;
@@ -794,7 +873,6 @@ SDL_EVDEV_device_removed(const char *dev_path)
     return -1;
 }
 
-
 #endif /* SDL_INPUT_LINUXEV */
 
 /* vi: set ts=4 sw=4 expandtab: */
