@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -25,7 +25,7 @@
 /* This is the PSP implementation of the SDL joystick API */
 #include <pspctrl.h>
 
-#include <stdio.h>      /* For the definition of NULL */
+#include <stdio.h> /* For the definition of NULL */
 #include <stdlib.h>
 
 #include "../SDL_sysjoystick.h"
@@ -40,38 +40,39 @@ static const enum PspCtrlButtons button_map[] = {
     PSP_CTRL_TRIANGLE, PSP_CTRL_CIRCLE, PSP_CTRL_CROSS, PSP_CTRL_SQUARE,
     PSP_CTRL_LTRIGGER, PSP_CTRL_RTRIGGER,
     PSP_CTRL_DOWN, PSP_CTRL_LEFT, PSP_CTRL_UP, PSP_CTRL_RIGHT,
-    PSP_CTRL_SELECT, PSP_CTRL_START, PSP_CTRL_HOME, PSP_CTRL_HOLD };
-static int analog_map[256];  /* Map analog inputs to -32768 -> 32767 */
+    PSP_CTRL_SELECT, PSP_CTRL_START, PSP_CTRL_HOME, PSP_CTRL_HOLD
+};
+static int analog_map[256]; /* Map analog inputs to -32768 -> 32767 */
 
 typedef struct
 {
-  int x;
-  int y;
+    int x;
+    int y;
 } point;
 
 /* 4 points define the bezier-curve. */
 static point a = { 0, 0 };
-static point b = { 50, 0  };
+static point b = { 50, 0 };
 static point c = { 78, 32767 };
 static point d = { 128, 32767 };
 
 /* simple linear interpolation between two points */
-static SDL_INLINE void lerp (point *dest, point *pt_a, point *pt_b, float t)
+static SDL_INLINE void lerp(point *dest, point *pt_a, point *pt_b, float t)
 {
-    dest->x = pt_a->x + (pt_b->x - pt_a->x)*t;
-    dest->y = pt_a->y + (pt_b->y - pt_a->y)*t;
+    dest->x = pt_a->x + (pt_b->x - pt_a->x) * t;
+    dest->y = pt_a->y + (pt_b->y - pt_a->y) * t;
 }
 
 /* evaluate a point on a bezier-curve. t goes from 0 to 1.0 */
 static int calc_bezier_y(float t)
 {
     point ab, bc, cd, abbc, bccd, dest;
-    lerp (&ab, &a, &b, t);           /* point between a and b */
-    lerp (&bc, &b, &c, t);           /* point between b and c */
-    lerp (&cd, &c, &d, t);           /* point between c and d */
-    lerp (&abbc, &ab, &bc, t);       /* point between ab and bc */
-    lerp (&bccd, &bc, &cd, t);       /* point between bc and cd */
-    lerp (&dest, &abbc, &bccd, t);   /* point on the bezier-curve */
+    lerp(&ab, &a, &b, t);         /* point between a and b */
+    lerp(&bc, &b, &c, t);         /* point between b and c */
+    lerp(&cd, &c, &d, t);         /* point between c and d */
+    lerp(&abbc, &ab, &bc, t);     /* point between ab and bc */
+    lerp(&bccd, &bc, &cd, t);     /* point between bc and cd */
+    lerp(&dest, &abbc, &bccd, t); /* point on the bezier-curve */
     return dest.y;
 }
 
@@ -89,11 +90,10 @@ static int PSP_JoystickInit(void)
 
     /* Create an accurate map from analog inputs (0 to 255)
        to SDL joystick positions (-32768 to 32767) */
-    for (i = 0; i < 128; i++)
-    {
-        float t = (float)i/127.0f;
-        analog_map[i+128] = calc_bezier_y(t);
-        analog_map[127-i] = -1 * analog_map[i+128];
+    for (i = 0; i < 128; i++) {
+        float t = (float)i / 127.0f;
+        analog_map[i + 128] = calc_bezier_y(t);
+        analog_map[127 - i] = -1 * analog_map[i + 128];
     }
 
     return 1;
@@ -111,11 +111,12 @@ static void PSP_JoystickDetect(void)
 /* Function to get the device-dependent name of a joystick */
 static const char *PSP_JoystickGetDeviceName(int device_index)
 {
-    if (device_index == 0)
+    if (device_index == 0) {
         return "PSP builtin joypad";
+    }
 
     SDL_SetError("No joystick available with that index");
-    return(NULL);
+    return NULL;
 }
 
 static const char *PSP_JoystickGetDevicePath(int index)
@@ -134,12 +135,9 @@ static void PSP_JoystickSetDevicePlayerIndex(int device_index, int player_index)
 
 static SDL_JoystickGUID PSP_JoystickGetDeviceGUID(int device_index)
 {
-    SDL_JoystickGUID guid;
-    /* the GUID is just the first 16 chars of the name for now */
+    /* the GUID is just the name for now */
     const char *name = PSP_JoystickGetDeviceName(device_index);
-    SDL_zero(guid);
-    SDL_memcpy(&guid, name, SDL_min(sizeof(guid), SDL_strlen(name)));
-    return guid;
+    return SDL_CreateJoystickGUIDForName(name);
 }
 
 /* Function to perform the mapping from device index to the instance id for this index */
@@ -213,11 +211,11 @@ static void PSP_JoystickUpdate(SDL_Joystick *joystick)
     y = pad.Ly;
 
     /* Axes */
-    if(old_x != x) {
+    if (old_x != x) {
         SDL_PrivateJoystickAxis(joystick, 0, analog_map[x]);
         old_x = x;
     }
-    if(old_y != y) {
+    if (old_y != y) {
         SDL_PrivateJoystickAxis(joystick, 1, analog_map[y]);
         old_y = y;
     }
@@ -225,13 +223,12 @@ static void PSP_JoystickUpdate(SDL_Joystick *joystick)
     /* Buttons */
     changed = old_buttons ^ buttons;
     old_buttons = buttons;
-    if(changed) {
+    if (changed) {
         for (i = 0; i < SDL_arraysize(button_map); i++) {
             if (changed & button_map[i]) {
                 SDL_PrivateJoystickButton(
                     joystick, i,
-                    (buttons & button_map[i]) ?
-                    SDL_PRESSED : SDL_RELEASED);
+                    (buttons & button_map[i]) ? SDL_PRESSED : SDL_RELEASED);
             }
         }
     }
@@ -247,14 +244,12 @@ static void PSP_JoystickQuit(void)
 {
 }
 
-static SDL_bool
-PSP_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
+static SDL_bool PSP_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
 {
     return SDL_FALSE;
 }
 
-SDL_JoystickDriver SDL_PSP_JoystickDriver =
-{
+SDL_JoystickDriver SDL_PSP_JoystickDriver = {
     PSP_JoystickInit,
     PSP_JoystickGetCount,
     PSP_JoystickDetect,
