@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -28,8 +28,7 @@
 #define URI_Dispatch 0x4e381
 #endif
 
-int
-SDL_SYS_OpenURL(const char *url)
+int SDL_SYS_OpenURL(const char *url)
 {
     _kernel_swi_regs regs;
     _kernel_oserror *error;
@@ -46,4 +45,3 @@ SDL_SYS_OpenURL(const char *url)
 }
 
 /* vi: set ts=4 sw=4 expandtab: */
-
