@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -28,20 +28,19 @@
 #include <sys/wait.h>
 #include <errno.h>
 
-int
-SDL_SYS_OpenURL(const char *url)
+int SDL_SYS_OpenURL(const char *url)
 {
     const pid_t pid1 = fork();
-    if (pid1 == 0) {  /* child process */
+    if (pid1 == 0) { /* child process */
         pid_t pid2;
         /* Clear LD_PRELOAD so Chrome opens correctly when this application is launched by Steam */
         unsetenv("LD_PRELOAD");
         /* Notice this is vfork and not fork! */
         pid2 = vfork();
-        if (pid2 == 0) {  /* Grandchild process will try to launch the url */
+        if (pid2 == 0) { /* Grandchild process will try to launch the url */
             execlp("xdg-open", "xdg-open", url, NULL);
             _exit(EXIT_FAILURE);
-        } else if (pid2 < 0) {   /* There was an error forking */
+        } else if (pid2 < 0) { /* There was an error forking */
             _exit(EXIT_FAILURE);
         } else {
             /* Child process doesn't wait for possibly-blocking grandchild. */
@@ -53,14 +52,14 @@ SDL_SYS_OpenURL(const char *url)
         int status;
         if (waitpid(pid1, &status, 0) == pid1) {
             if (WIFEXITED(status)) {
-                 if (WEXITSTATUS(status) == 0) {
-                     return 0;  /* success! */
-                 } else {
-                     return SDL_SetError("xdg-open reported error or failed to launch: %d", WEXITSTATUS(status));
-                 }
-             } else {
+                if (WEXITSTATUS(status) == 0) {
+                    return 0; /* success! */
+                } else {
+                    return SDL_SetError("xdg-open reported error or failed to launch: %d", WEXITSTATUS(status));
+                }
+            } else {
                 return SDL_SetError("xdg-open failed for some reason");
-             }
+            }
         } else {
             return SDL_SetError("Waiting on xdg-open failed: %s", strerror(errno));
         }
@@ -68,4 +67,3 @@ SDL_SYS_OpenURL(const char *url)
 }
 
 /* vi: set ts=4 sw=4 expandtab: */
-
