@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -46,8 +46,9 @@ static SDL_Window *FindSDLWindowForNSWindow(NSWindow *win)
     if (device && device->windows) {
         for (sdlwindow = device->windows; sdlwindow; sdlwindow = sdlwindow->next) {
             NSWindow *nswindow = ((__bridge SDL_WindowData *) sdlwindow->driverdata).nswindow;
-            if (win == nswindow)
+            if (win == nswindow) {
                 return sdlwindow;
+            }
         }
     }
 
@@ -192,8 +193,9 @@ static void Cocoa_DispatchEvent(NSEvent *theEvent)
     }
 
     /* Don't do anything if this was not an SDL window that was closed */
-    if (FindSDLWindowForNSWindow(win) == NULL)
+    if (FindSDLWindowForNSWindow(win) == NULL) {
         return;
+    }
 
     /* HACK: Make the next window in the z-order key when the key window is
      * closed. The custom event loop and/or windowing code we have seems to
@@ -312,8 +314,7 @@ static void Cocoa_DispatchEvent(NSEvent *theEvent)
 
 static SDLAppDelegate *appDelegate = nil;
 
-static NSString *
-GetApplicationName(void)
+static NSString *GetApplicationName(void)
 {
     NSString *appName;
 
@@ -330,8 +331,7 @@ GetApplicationName(void)
     return appName;
 }
 
-static bool
-LoadMainMenuNibIfAvailable(void)
+static bool LoadMainMenuNibIfAvailable(void)
 {
 #if MAC_OS_X_VERSION_MAX_ALLOWED >= 1080
     NSDictionary *infoDict;
@@ -344,20 +344,19 @@ LoadMainMenuNibIfAvailable(void)
     infoDict = [[NSBundle mainBundle] infoDictionary];
     if (infoDict) {
         mainNibFileName = [infoDict valueForKey:@"NSMainNibFile"];
-        
+
         if (mainNibFileName) {
             success = [[NSBundle mainBundle] loadNibNamed:mainNibFileName owner:[NSApplication sharedApplication] topLevelObjects:nil];
         }
     }
-    
+
     return success;
 #else
     return false;
 #endif
 }
 
-static void
-CreateApplicationMenus(void)
+static void CreateApplicationMenus(void)
 {
     NSString *appName;
     NSString *title;
@@ -370,7 +369,7 @@ CreateApplicationMenus(void)
     if (NSApp == nil) {
         return;
     }
-    
+
     mainMenu = [[NSMenu alloc] init];
 
     /* Create the main menu bar */
@@ -391,7 +390,7 @@ CreateApplicationMenus(void)
     [appleMenu addItem:[NSMenuItem separatorItem]];
 
     serviceMenu = [[NSMenu alloc] initWithTitle:@""];
-    menuItem = (NSMenuItem *)[appleMenu addItemWithTitle:@"Services" action:nil keyEquivalent:@""];
+    menuItem = [appleMenu addItemWithTitle:@"Services" action:nil keyEquivalent:@""];
     [menuItem setSubmenu:serviceMenu];
 
     [NSApp setServicesMenu:serviceMenu];
@@ -428,7 +427,7 @@ CreateApplicationMenus(void)
     [windowMenu addItemWithTitle:@"Minimize" action:@selector(performMiniaturize:) keyEquivalent:@"m"];
 
     [windowMenu addItemWithTitle:@"Zoom" action:@selector(performZoom:) keyEquivalent:@""];
-    
+
     /* Add the fullscreen toggle menu option. */
     /* Cocoa should update the title to Enter or Exit Full Screen automatically.
      * But if not, then just fallback to Toggle Full Screen.
@@ -446,8 +445,7 @@ CreateApplicationMenus(void)
     [NSApp setWindowsMenu:windowMenu];
 }
 
-void
-Cocoa_RegisterApp(void)
+void Cocoa_RegisterApp(void)
 { @autoreleasepool
 {
     /* This can get called more than once! Be careful what you initialize! */
@@ -468,7 +466,7 @@ Cocoa_RegisterApp(void)
          */
         if ([NSApp mainMenu] == nil) {
             bool nibLoaded;
-            
+
             nibLoaded = LoadMainMenuNibIfAvailable();
             if (!nibLoaded) {
                 CreateApplicationMenus();
@@ -505,8 +503,7 @@ Cocoa_RegisterApp(void)
     }
 }}
 
-int
-Cocoa_PumpEventsUntilDate(_THIS, NSDate *expiration, bool accumulate)
+int Cocoa_PumpEventsUntilDate(_THIS, NSDate *expiration, bool accumulate)
 {
     for ( ; ; ) {
         NSEvent *event = [NSApp nextEventMatchingMask:NSEventMaskAny untilDate:expiration inMode:NSDefaultRunLoopMode dequeue:YES ];
@@ -527,8 +524,7 @@ Cocoa_PumpEventsUntilDate(_THIS, NSDate *expiration, bool accumulate)
     return 1;
 }
 
-int
-Cocoa_WaitEventTimeout(_THIS, int timeout)
+int Cocoa_WaitEventTimeout(_THIS, int timeout)
 { @autoreleasepool
 {
     if (timeout > 0) {
@@ -543,8 +539,7 @@ Cocoa_WaitEventTimeout(_THIS, int timeout)
     return 1;
 }}
 
-void
-Cocoa_PumpEvents(_THIS)
+void Cocoa_PumpEvents(_THIS)
 { @autoreleasepool
 {
     Cocoa_PumpEventsUntilDate(_this, [NSDate distantPast], true);
@@ -566,8 +561,7 @@ void Cocoa_SendWakeupEvent(_THIS, SDL_Window *window)
     [NSApp postEvent: event atStart: YES];
 }}
 
-void
-Cocoa_SuspendScreenSaver(_THIS)
+void Cocoa_SuspendScreenSaver(_THIS)
 { @autoreleasepool
 {
     SDL_VideoData *data = (__bridge SDL_VideoData *)_this->driverdata;
