@@ -318,10 +318,13 @@ static void WIN_AddDisplay(_THIS, HMONITOR hMonitor, const MONITORINFOEXW *info,
         if (SDL_wcscmp(driverdata->DeviceName, info->szDevice) == 0) {
             SDL_bool moved = (index != i);
 
+            if (index >= _this->num_displays) {
+                return;
+            }
+
             if (moved) {
                 SDL_VideoDisplay tmp;
 
-                SDL_assert(index < _this->num_displays);
                 SDL_memcpy(&tmp, &_this->displays[index], sizeof(tmp));
                 SDL_memcpy(&_this->displays[index], &_this->displays[i], sizeof(tmp));
                 SDL_memcpy(&_this->displays[i], &tmp, sizeof(tmp));
