@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -33,12 +33,15 @@ quit(int rc)
 static const char *
 getprioritystr(SDL_ThreadPriority priority)
 {
-    switch(priority)
-    {
-    case SDL_THREAD_PRIORITY_LOW: return "SDL_THREAD_PRIORITY_LOW";
-    case SDL_THREAD_PRIORITY_NORMAL: return "SDL_THREAD_PRIORITY_NORMAL";
-    case SDL_THREAD_PRIORITY_HIGH: return "SDL_THREAD_PRIORITY_HIGH";
-    case SDL_THREAD_PRIORITY_TIME_CRITICAL: return "SDL_THREAD_PRIORITY_TIME_CRITICAL";
+    switch (priority) {
+    case SDL_THREAD_PRIORITY_LOW:
+        return "SDL_THREAD_PRIORITY_LOW";
+    case SDL_THREAD_PRIORITY_NORMAL:
+        return "SDL_THREAD_PRIORITY_NORMAL";
+    case SDL_THREAD_PRIORITY_HIGH:
+        return "SDL_THREAD_PRIORITY_HIGH";
+    case SDL_THREAD_PRIORITY_TIME_CRITICAL:
+        return "SDL_THREAD_PRIORITY_TIME_CRITICAL";
     }
 
     return "???";
@@ -51,20 +54,21 @@ ThreadFunc(void *data)
 
     SDL_TLSSet(tls, "baby thread", NULL);
     SDL_Log("Started thread %s: My thread id is %lu, thread data = %s\n",
-           (char *) data, SDL_ThreadID(), (const char *)SDL_TLSGet(tls));
+            (char *)data, SDL_ThreadID(), (const char *)SDL_TLSGet(tls));
     while (alive) {
-        SDL_Log("Thread '%s' is alive!\n", (char *) data);
+        SDL_Log("Thread '%s' is alive!\n", (char *)data);
 
         if (testprio) {
             SDL_Log("SDL_SetThreadPriority(%s):%d\n", getprioritystr(prio), SDL_SetThreadPriority(prio));
-            if (++prio > SDL_THREAD_PRIORITY_TIME_CRITICAL)
+            if (++prio > SDL_THREAD_PRIORITY_TIME_CRITICAL) {
                 prio = SDL_THREAD_PRIORITY_LOW;
+            }
         }
 
         SDL_Delay(1 * 1000);
     }
-    SDL_Log("Thread '%s' exiting!\n", (char *) data);
-    return (0);
+    SDL_Log("Thread '%s' exiting!\n", (char *)data);
+    return 0;
 }
 
 static void
@@ -76,8 +80,7 @@ killed(int sig)
     quit(0);
 }
 
-int
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
     int arg = 1;
     SDL_Thread *thread;
@@ -88,7 +91,13 @@ main(int argc, char *argv[])
     /* Load the SDL library */
     if (SDL_Init(0) < 0) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Couldn't initialize SDL: %s\n", SDL_GetError());
-        return (1);
+        return 1;
+    }
+
+    if (SDL_getenv("SDL_TESTS_QUICK") != NULL) {
+        SDL_Log("Not running slower tests");
+        SDL_Quit();
+        return 0;
     }
 
     while (argv[arg] && *argv[arg] == '-') {
@@ -117,14 +126,14 @@ main(int argc, char *argv[])
     SDL_Log("Main thread data finally: %s\n", (const char *)SDL_TLSGet(tls));
 
     alive = 1;
-    signal(SIGTERM, killed);
+    (void)signal(SIGTERM, killed);
     thread = SDL_CreateThread(ThreadFunc, "Two", "#2");
     if (thread == NULL) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Couldn't create thread: %s\n", SDL_GetError());
         quit(1);
     }
-    raise(SIGTERM);
+    (void)raise(SIGTERM);
 
-    SDL_Quit();                 /* Never reached */
-    return (0);                 /* Never reached */
+    SDL_Quit(); /* Never reached */
+    return 0;   /* Never reached */
 }
